import signal
from types import FrameType

from remote_pdb import RemotePdb

DEFAULT_SIGNAL = signal.SIGUSR1
DEFAULT_HOST = "localhost"
DEFAULT_PORT = 9999


def install(signum=DEFAULT_SIGNAL, bind_host=DEFAULT_HOST, bind_port=DEFAULT_PORT):
    # type: (int, str, int) -> None
    def _set_trace(received_signum, frame):
        # type: (int, FrameType) -> None
        RemotePdb(host=bind_host, port=bind_port).set_trace(frame)

    signal.signal(signum, _set_trace)


__all__ = ["DEFAULT_SIGNAL", "DEFAULT_HOST", "DEFAULT_PORT", "install"]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['adhoc_pdb']

package_data = \
{'': ['*']}

install_requires = \
['remote-pdb>=2.0,<3.0']

setup_kwargs = {
    'name': 'adhoc-pdb',
    'version': '0.1.0',
    'description': '',
    'long_description': None,
    'author': 'Yehonatan Zecharia',
    'author_email': 'yonti95@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
}


setup(**setup_kwargs)
